@@ -1,13 +1,13 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
 
-Vagrant.require "digest/sha1"
-Vagrant.require "fileutils"
-Vagrant.require "monitor"
-Vagrant.require "tmpdir"
-Vagrant.require "log4r"
-Vagrant.require "vagrant/util/platform"
-Vagrant.require "vagrant/util/subprocess"
+require "digest/sha1"
+require "fileutils"
+require "monitor"
+require "tmpdir"
+require "log4r"
+require "vagrant/util/platform"
+require "vagrant/util/subprocess"
 
 module Vagrant
   # Represents a collection a boxes found on disk. This provides methods
@@ -18,8 +18,6 @@ module Vagrant
     VAGRANT_SLASH = "-VAGRANTSLASH-".freeze
     VAGRANT_COLON = "-VAGRANTCOLON-".freeze
 
-    autoload :Remote, "vagrant/box_collection/remote"
-
     # The directory where the boxes in this collection are stored.
     #
     # A box collection matches a very specific folder structure that Vagrant
@@ -388,7 +386,7 @@ module Vagrant
 
                 return Box.new(
                   name, provider, version_dir_map[v.to_s], providerdir,
-                  architecture: architecture, metadata_url: metadata_url, hook: @hook
+                  architecture: box_architecture, metadata_url: metadata_url, hook: @hook
                 )
               end
             end
@@ -410,7 +408,7 @@ module Vagrant
 
             return Box.new(
               name, provider, version_dir_map[v.to_s], providerdir,
-              architecture: architecture, metadata_url: metadata_url, hook: @hook
+              architecture: box_architecture, metadata_url: metadata_url, hook: @hook
             )
           end
         end
