@@ -1,20 +1,20 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
 
-Vagrant.require 'fileutils'
-Vagrant.require 'json'
-Vagrant.require 'pathname'
-Vagrant.require 'set'
-Vagrant.require 'thread'
+require 'fileutils'
+require 'json'
+require 'pathname'
+require 'set'
+require 'thread'
 
-Vagrant.require 'log4r'
+require 'log4r'
 
-Vagrant.require 'vagrant/util/file_mode'
-Vagrant.require 'vagrant/util/platform'
-Vagrant.require 'vagrant/util/hash_with_indifferent_access'
-Vagrant.require "vagrant/util/silence_warnings"
-Vagrant.require "vagrant/vagrantfile"
-Vagrant.require "vagrant/version"
+require 'vagrant/util/file_mode'
+require 'vagrant/util/platform'
+require 'vagrant/util/hash_with_indifferent_access'
+require "vagrant/util/silence_warnings"
+require "vagrant/vagrantfile"
+require "vagrant/version"
 
 module Vagrant
   # A "Vagrant environment" represents a configuration of how Vagrant
@@ -22,8 +22,6 @@ module Vagrant
   # etc. In day-to-day usage, every `vagrant` invocation typically
   # leads to a single Vagrant environment.
   class Environment
-    autoload :Remote, "vagrant/environment/remote"
-
     # This is the current version that this version of Vagrant is
     # compatible with in the home directory.
     #
