@@ -1,7 +1,7 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
 
-Vagrant.require "vagrant/capability_host"
+require "vagrant/capability_host"
 
 module Vagrant
   # This class handles host-OS specific interactions. It is responsible for
@@ -12,8 +12,6 @@ module Vagrant
   class Host
     include CapabilityHost
 
-    autoload :Remote, "vagrant/host/remote"
-
     def initialize(host, hosts, capabilities, env)
       initialize_capabilities!(host, hosts, capabilities, env)
     end
