@@ -4,17 +4,15 @@
 require_relative "./util/ssh"
 require_relative "./action/builtin/mixin_synced_folders"
 
-Vagrant.require "digest/md5"
-Vagrant.require "thread"
-Vagrant.require "log4r"
+require "digest/md5"
+require "thread"
+require "log4r"
 
 module Vagrant
   # This represents a machine that Vagrant manages. This provides a singular
   # API for querying the state and making state changes to the machine, which
   # is backed by any sort of provider (VirtualBox, VMware, etc.).
   class Machine
-    autoload :Remote, "vagrant/machine/remote"
-
     extend Vagrant::Action::Builtin::MixinSyncedFolders
 
     # The box that is backing this machine.
@@ -350,6 +348,7 @@ module Vagrant
           end
         end
       else
+        @logger.debug("machine ID has been unset, deregistering machine and removing data directory")
         # Delete the file, since the machine is now destroyed
         id_file.delete if id_file && id_file.file?
         uid_file.delete if uid_file && uid_file.file?
@@ -489,6 +488,8 @@ module Vagrant
       info[:forward_x11] = @config.ssh.forward_x11
       info[:forward_env] = @config.ssh.forward_env
       info[:connect_timeout] = @config.ssh.connect_timeout
+      info[:connect_retries] = @config.ssh.connect_retries
+      info[:connect_retry_delay] = @config.ssh.connect_retry_delay
 
       info[:ssh_command] = @config.ssh.ssh_command if @config.ssh.ssh_command
 
