@@ -1,8 +1,8 @@
 # Copyright (c) HashiCorp, Inc.
 # SPDX-License-Identifier: BUSL-1.1
 
-Vagrant.require "fileutils"
-Vagrant.require "log4r"
+require "fileutils"
+require "log4r"
 
 module VagrantPlugins
   module HyperV
