@@ -27,7 +27,10 @@ module VagrantPlugins
         # Version of VirtualBox on darwin platform that ignores restrictions
         DARWIN_IGNORE_HOSTONLY_VALIDATE_VERSION = Gem::Version.new("7.0.0")
         # Default valid range for hostonly networks
-        HOSTONLY_DEFAULT_RANGE = [IPAddr.new("192.168.56.0/21").freeze].freeze
+        HOSTONLY_DEFAULT_RANGE = [
+          IPAddr.new("192.168.56.0/21").freeze,
+          IPAddr.new("fe80::/10").freeze
+        ].freeze
 
         include Vagrant::Util::NetworkIP
         include Vagrant::Util::ScopedHashOverride
@@ -359,9 +362,9 @@ module VagrantPlugins
           # Find the hostonly interface name if display name was
           # provided
           if options[:name]
-            hostif = @env[:machine].provider.driver.read_host_only_networks.detect { |interface|
+            hostif = @env[:machine].provider.driver.read_host_only_interfaces.detect { |interface|
               interface[:name] == options[:name] ||
-                interface[:vboxnetworkname] == options[:name]
+                interface[:display_name] == options[:name]
             }
             options[:name] = hostif[:name] if hostif
           end
