@@ -2,7 +2,6 @@
 # SPDX-License-Identifier: BUSL-1.1
 
 require 'log4r'
-
 require "vagrant/util/platform"
 
 require File.expand_path("../base", __FILE__)
@@ -10,12 +9,12 @@ require File.expand_path("../base", __FILE__)
 module VagrantPlugins
   module ProviderVirtualBox
     module Driver
-      # Driver for VirtualBox 4.0.x
-      class Version_4_0 < Base
+      # Driver for VirtualBox 4.1.x
+      class Version_4_1 < Base
         def initialize(uuid)
           super()
 
-          @logger = Log4r::Logger.new("vagrant::provider::virtualbox_4_0")
+          @logger = Log4r::Logger.new("vagrant::provider::virtualbox_4_1")
           @uuid = uuid
         end
 
@@ -31,12 +30,23 @@ module VagrantPlugins
         def clear_shared_folders
           info = execute("showvminfo", @uuid, "--machinereadable", retryable: true)
           info.split("\n").each do |line|
-            if name = line[/^SharedFolderNameMachineMapping\d+="(.+?)"$/, 1]
-              execute("sharedfolder", "remove", @uuid, "--name", name)
+            if folder = line[/^SharedFolderNameMachineMapping\d+="(.+?)"$/, 1]
+              execute("sharedfolder", "remove", @uuid, "--name", folder)
             end
           end
         end
 
+        def clonevm(master_id, snapshot_name)
+          machine_name = "temp_clone_#{(Time.now.to_f * 1000.0).to_i}_#{rand(100000)}"
+          args = ["--register", "--name", machine_name]
+          if snapshot_name
+            args += ["--snapshot", snapshot_name, "--options", "link"]
+          end
+
+          execute("clonevm", master_id, *args)
+          return get_machine_id(machine_name)
+        end
+
         def create_dhcp_server(network, options)
           execute("dhcpserver", "add", "--ifname", network,
                   "--ip", options[:dhcp_ip],
@@ -74,6 +84,86 @@ module VagrantPlugins
           }
         end
 
+        def create_snapshot(machine_id, snapshot_name)
+          execute("snapshot", machine_id, "take", snapshot_name)
+        end
+
+        def delete_snapshot(machine_id, snapshot_name)
+          # Start with 0%
+          last = 0
+          total = ""
+          yield 0 if block_given?
+
+          # Snapshot and report the % progress
+          execute("snapshot", machine_id, "delete", snapshot_name) do |type, data|
+            if type == :stderr
+              # Append the data so we can see the full view
+              total << data.gsub("\r", "")
+
+              # Break up the lines. We can't get the progress until we see an "OK"
+              lines = total.split("\n")
+
+              # The progress of the import will be in the last line. Do a greedy
+              # regular expression to find what we're looking for.
+              match = /.+(\d{2})%/.match(lines.last)
+              if match
+                current = match[1].to_i
+                if current > last
+                  last = current
+                  yield current if block_given?
+                end
+              end
+            end
+          end
+        end
+
+        def list_snapshots(machine_id)
+          output = execute(
+            "snapshot", machine_id, "list", "--machinereadable",
+            retryable: true)
+
+          result = []
+          output.split("\n").each do |line|
+            if line =~ /^SnapshotName.*?="(.+?)"$/i
+              result << $1.to_s
+            end
+          end
+
+          result.sort
+        rescue Vagrant::Errors::VBoxManageError => e
+          d = e.extra_data
+          return [] if d[:stderr].include?("does not have") || d[:stdout].include?("does not have")
+          raise
+        end
+
+        def restore_snapshot(machine_id, snapshot_name)
+          # Start with 0%
+          last = 0
+          total = ""
+          yield 0 if block_given?
+
+          execute("snapshot", machine_id, "restore", snapshot_name) do |type, data|
+            if type == :stderr
+              # Append the data so we can see the full view
+              total << data.gsub("\r", "")
+
+              # Break up the lines. We can't get the progress until we see an "OK"
+              lines = total.split("\n")
+
+              # The progress of the import will be in the last line. Do a greedy
+              # regular expression to find what we're looking for.
+              match = /.+(\d{2})%/.match(lines.last)
+              if match
+                current = match[1].to_i
+                if current > last
+                  last = current
+                  yield current if block_given?
+                end
+              end
+            end
+          end
+        end
+
         def delete
           execute("unregistervm", @uuid, "--delete")
         end
@@ -81,18 +171,18 @@ module VagrantPlugins
         def delete_unused_host_only_networks
           networks = []
           execute("list", "hostonlyifs").split("\n").each do |line|
-            if network_name = line[/^Name:\s+(.+?)$/, 1]
-              networks << network_name
+            if network = line[/^Name:\s+(.+?)$/, 1]
+              networks << network
             end
           end
 
           execute("list", "vms").split("\n").each do |line|
-            if vm_name = line[/^".+?"\s+\{(.+?)\}$/, 1]
+            if vm = line[/^".+?"\s+\{(.+?)\}$/, 1]
               begin
-                info = execute("showvminfo", vm_name, "--machinereadable", retryable: true)
+                info = execute("showvminfo", vm, "--machinereadable", retryable: true)
                 info.split("\n").each do |line|
-                  if network_name = line[/^hostonlyadapter\d+="(.+?)"$/, 1]
-                    networks.delete(network_name)
+                  if adapter = line[/^hostonlyadapter\d+="(.+?)"$/, 1]
+                    networks.delete(adapter)
                   end
                 end
               rescue Vagrant::Errors::VBoxManageError => e
@@ -134,6 +224,11 @@ module VagrantPlugins
                           adapter[:hostonly]])
             end
 
+            if adapter[:intnet]
+              args.concat(["--intnet#{adapter[:adapter]}",
+                          adapter[:intnet]])
+            end
+
             if adapter[:mac_address]
               args.concat(["--macaddress#{adapter[:adapter]}",
                           adapter[:mac_address]])
@@ -172,6 +267,13 @@ module VagrantPlugins
           execute("modifyvm", @uuid, *args) if !args.empty?
         end
 
+        def get_machine_id(machine_name)
+          output = execute("list", "vms", retryable: true)
+          match = /^"#{Regexp.escape(machine_name)}" \{(.+?)\}$/.match(output)
+          return match[1].to_s if match
+          nil
+        end
+
         def halt
           execute("controlvm", @uuid, "poweroff")
         end
@@ -485,6 +587,13 @@ module VagrantPlugins
               "--hostpath",
               folder[:hostpath]]
             args << "--transient" if folder.key?(:transient) && folder[:transient]
+
+            if folder[:SharedFoldersEnableSymlinksCreate]
+              # Enable symlinks on the shared folder
+              execute("setextradata", @uuid, "VBoxInternal2/SharedFoldersEnableSymlinksCreate/#{folder[:name]}", "1")
+            end
+
+            # Add the shared folder
             execute("sharedfolder", "add", @uuid, *args)
           end
         end
@@ -533,9 +642,9 @@ module VagrantPlugins
                 "--name", name,
                 "--transient")
 
-            execute(
-              "setextradata", @uuid,
-              "VBoxInternal2/SharedFoldersEnableSymlinksCreate/#{name}")
+              execute(
+                "setextradata", @uuid,
+                "VBoxInternal2/SharedFoldersEnableSymlinksCreate/#{name}")
             rescue Vagrant::Errors::VBoxManageError => e
               if e.extra_data[:stderr].include?("VBOX_E_FILE_ERROR")
                 # The folder doesn't exist. ignore.
@@ -568,7 +677,23 @@ module VagrantPlugins
         end
 
         def vm_exists?(uuid)
-          raw("showvminfo", uuid).exit_code == 0
+          5.times do |i|
+            result = raw("showvminfo", uuid)
+            return true if result.exit_code == 0
+
+            # If vboxmanage returned VBOX_E_OBJECT_NOT_FOUND,
+            # then the vm truly does not exist. Any other error might be transient
+            return false if result.stderr.include?("VBOX_E_OBJECT_NOT_FOUND")
+
+            # Sleep a bit though to give VirtualBox time to fix itself
+            sleep 2
+          end
+
+          # If we reach this point, it means that we consistently got the
+          # failure, do a standard vboxmanage now. This will raise an
+          # exception if it fails again.
+          execute("showvminfo", uuid)
+          return true
         end
       end
     end
